<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !function_exists( 'nmd_customizer_register_top' ) ) {
	function nmd_customizer_register_top( $wp_customize ) {
		/**
		 * パネルの追加 =========================================================
		 */
		$wp_customize->add_panel( 'nmd_toppage_panel', array(
            'title'    => __('[Nomad]トップページの設定', NMD_TEXT_DOMAIN),
            'priority' => 190,
		));
		/**
		 * ヘッダー画像のタイプ =========================================================
		 */
		$wp_customize->add_section('nmd_section_header_image_width', array(
			'title'       => __('ヘッダー画像のタイプ', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
		));
		// テキストタイプ
		$wp_customize->add_setting('nmd_header_image_width', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
			'default'			=> 'full',
		));
		$wp_customize->add_control('nmd_header_image_width', array(
			'label'			=> __('ヘッダー画像のレイアウトタイプ', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image_width',
			'settings'		=> 'nmd_header_image_width',
			'type'			=> 'radio',
			'choices'	=> array(
				'full'			=> __('ウィンドウいっぱい', NMD_TEXT_DOMAIN),
				'contents'		=> __('コンテンツ幅', NMD_TEXT_DOMAIN),
				'independent'	=> __('コンテンツ幅(独立)', NMD_TEXT_DOMAIN),
				'slim'			=> __('コンテンツ幅(スリム)', NMD_TEXT_DOMAIN),
			),
		));
		$wp_customize->selective_refresh->add_partial('nmd_header_image_width', array(
			'selector' => '#main-visual',
		));
		/**
		 * ヘッダー画像のテキスト =========================================================
		 */
		$wp_customize->add_section('nmd_section_header_image', array(
			'title'       => __('ヘッダー画像のテキスト', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
		));
		// テキストタイプ
		$wp_customize->add_setting('nmd_header_image_text_type', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
			'default'			=> 'title',
		));
		$wp_customize->add_control('nmd_header_image_text_type', array(
			'label'			=> __('ヘッダー画像にのせるテキスト', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image',
			'settings'		=> 'nmd_header_image_text_type',
			'type'			=> 'radio',
			'choices'	=> array(
				'title'		=> __('サイトタイトル', NMD_TEXT_DOMAIN),
				'custom'	=> __('カスタム', NMD_TEXT_DOMAIN),
				'none'		=> __('テキストなし', NMD_TEXT_DOMAIN),
			),
		));
		$wp_customize->selective_refresh->add_partial('nmd_header_image_text_type', array(
			'selector' => '#c-mv-title',
		));
		// カスタムテキスト
		$wp_customize->add_setting('nmd_header_image_text', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_html_available_br',
		));
		$wp_customize->add_control('nmd_header_image_text', array(
			'label'			=> __('カスタムを選んだ場合はこちらにテキストを入力してください。改行は&lt;br&gt;タグが使えます。', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image',
			'settings'		=> 'nmd_header_image_text',
			'type'			=> 'text',
		));

		$wp_customize->add_setting( 'nmd_header_image_font_size_heading', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_header_image_font_size_heading', array(
			'section' => 'nmd_section_header_image',
			'label'   => __('テキストのフォントサイズ', NMD_TEXT_DOMAIN),
		) ) );

		$wp_customize->add_setting('nmd_header_image_font_size', array(
			'type' => 'option',
			'default' => '40',
			'sanitize_callback' => 'nmd_sanitize_number_range',
		));
		$wp_customize->add_control('nmd_header_image_font_size', array(
			'label'       => __('フォントサイズ（PC）', NMD_TEXT_DOMAIN),
			'description' => __('16~60pxの範囲で設定できます。', NMD_TEXT_DOMAIN),
			'section'     => 'nmd_section_header_image',
			'settings'    => 'nmd_header_image_font_size',
			'type'        => 'number',
			'input_attrs' => array(
				'step' => '1',
				'min'  => '16',
				'max' => '60'
			),
		));
		$wp_customize->add_setting('nmd_header_image_font_size_sp', array(
			'type' => 'option',
			'default' => '20',
			'sanitize_callback' => 'nmd_sanitize_number_range',
		));
		$wp_customize->add_control('nmd_header_image_font_size_sp', array(
			'label'       => __('フォントサイズ（スマホ）', NMD_TEXT_DOMAIN),
			'description' => __('14~40pxの範囲で設定できます。', NMD_TEXT_DOMAIN),
			'section'     => 'nmd_section_header_image',
			'settings'    => 'nmd_header_image_font_size_sp',
			'type'        => 'number',
			'input_attrs' => array(
				'step' => '1',
				'min'  => '14',
				'max' => '40'
			),
		));
		/**
		 * ヘッダー画像のテキスト下 =========================================================
		 */
		$wp_customize->add_section('nmd_section_header_image_under', array(
			'title'       => __('ヘッダー画像のテキスト下', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
		));
		// コンセプト文
		$wp_customize->add_setting('nmd_header_image_concept', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_html_available_br',
		));
		$wp_customize->add_control('nmd_header_image_concept', array(
			'label'			=> __('コンセプト文', NMD_TEXT_DOMAIN),
			'description'	=> __('ヘッダーテキストの下に表示させる文章。改行は&lt;br&gt;タグが使えます。', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image_under',
			'settings'		=> 'nmd_header_image_concept',
			'type'			=> 'textarea',
		));
		$wp_customize->selective_refresh->add_partial('nmd_header_image_concept', array(
			'selector' => '#title-sub-content',
		));
		// コンセプト文テキストカラー
		$wp_customize->add_setting('nmd_header_image_concept_color', array(
			'type'				=> 'option',
			'default'			=> '#fff',
			'sanitize_callback'	=> 'sanitize_hex_color',
		));
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'nmd_header_image_concept_color', array(
			'label'		=> __('コンセプト文の文字色', NMD_TEXT_DOMAIN),
			'section'	=> 'nmd_section_header_image_under',
			'settings'	=> 'nmd_header_image_concept_color',
		)));
		// リンク先URL
		$wp_customize->add_setting('nmd_header_image_btn_url', array(
			'type'				=> 'option',
			'sanitize_callback' => 'esc_url',
		));
		$wp_customize->add_control('nmd_header_image_btn_url', array(
			'label'			=> __('ボタンのリンク先URL', NMD_TEXT_DOMAIN),
			'description'	=> __('リンクを設定すると、ボタンが表示されます', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image_under',
			'settings'		=> 'nmd_header_image_btn_url',
			'type'			=> 'text',
			'input_attrs' => array(
				'placeholder' => __('https://example.com', NMD_TEXT_DOMAIN),
			),
		));
		$wp_customize->selective_refresh->add_partial('nmd_header_image_btn_url', array(
			'selector' => '#title-sub-content-btn',
		));
		// ボタンのテキスト
		$wp_customize->add_setting('nmd_header_image_btn_text', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> __('リンク', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_control('nmd_header_image_btn_text', array(
			'label'			=> __('ボタンのテキスト', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_header_image_under',
			'settings'		=> 'nmd_header_image_btn_text',
			'type'			=> 'text',
		));
		// ボタンのカラー
		$wp_customize->add_setting('nmd_header_image_btn_color', array(
			'type'				=> 'option',
			'default'			=> '#29CAD8',
			'sanitize_callback'	=> 'sanitize_hex_color',
		));
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'nmd_header_image_btn_color', array(
			'label'		=> __('ボタンのカラー', NMD_TEXT_DOMAIN),
			'section'	=> 'nmd_section_header_image_under',
			'settings'	=> 'nmd_header_image_btn_color',
		)));

		/**
		 * スライドショー =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_carousel', array(
			'title'       => __('スライドショー', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページに表示するスライドショーの設定', NMD_TEXT_DOMAIN)
		) );
		$wp_customize->add_setting( 'nmd_carousel_entry_id', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_carousel_entry_id', array(
			'label'			=> __('スライドショー', NMD_TEXT_DOMAIN),
			'description'	=> __('スライドショーに表示する記事IDをコンマ区切りで記述してください。<br>例：1,5,12', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_carousel',
			'settings'		=> 'nmd_carousel_entry_id',
			'type'			=> 'text',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_carousel_entry_id', array(
			'selector' => '#carousel',
		) );

		/**
		 * 全幅スライダー =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_slider', array(
			'title'       => __('全幅スライダー', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページに表示する全幅スライダーの設定', NMD_TEXT_DOMAIN)
		) );
		$wp_customize->add_setting( 'nmd_slider_entry_id', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_slider_entry_id', array(
			'label'			=> __('全幅スライダー', NMD_TEXT_DOMAIN),
			'description'	=> __('全幅スライダーに表示する記事IDをコンマ区切りで記述してください。<br>例：1,5,12', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_slider',
			'settings'		=> 'nmd_slider_entry_id',
			'type'			=> 'text',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_slider_entry_id', array(
			'selector' => '#pickup',
		) );

		/**
		 * ピックアップ記事 =========================================================
		 */
		$wp_customize->add_section('nmd_section_pickup_article', array(
			'title'       => __('ピックアップ記事', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページに表示するピックアップ記事の設定', NMD_TEXT_DOMAIN)
		));
		$wp_customize->add_setting('nmd_pickup_article_id', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		));
		$wp_customize->add_control('nmd_pickup_article_id', array(
			'label'			=> __('ピックアップ記事', NMD_TEXT_DOMAIN),
			'description'	=> __('ピックアップ記事に表示する記事IDをコンマ区切りで記述してください。<br>例：1,5,12', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_pickup_article',
			'settings'		=> 'nmd_pickup_article_id',
			'type'			=> 'text',
		));
		$wp_customize->selective_refresh->add_partial('nmd_pickup_article_id', array(
			'selector' => '#pickup-article',
		));
		$wp_customize->add_setting('nmd_pickup_article_type_1column', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
			'default'			=> 'big1-mid2',
		));
		$wp_customize->add_control('nmd_pickup_article_type_1column', array(
			'label'		=> __('1カラム時のピックアップ記事レイアウト', NMD_TEXT_DOMAIN),
			'section'	=> 'nmd_section_pickup_article',
			'settings'	=> 'nmd_pickup_article_type_1column',
			'type'		=> 'select',
			'choices'	=> array(
				'big1-mid2'	=> __('大1+中2（3記事）', NMD_TEXT_DOMAIN),
				'mid2-mid2'	=> __('中2+中2（4記事）', NMD_TEXT_DOMAIN),
				'big1-sm2'	=> __('大1+小2（3記事）', NMD_TEXT_DOMAIN),
				'mid1-mid2'	=> __('中1+中2（3記事）', NMD_TEXT_DOMAIN),
				'mid2-sm2'	=> __('中2+小2（4記事）', NMD_TEXT_DOMAIN),
			),
		));
		$wp_customize->add_setting('nmd_pickup_article_type_2column', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
			'default'			=> 'sm1-mid2',
		));
		$wp_customize->add_control('nmd_pickup_article_type_2column', array(
			'label'		=> __('2カラム時のピックアップ記事レイアウト', NMD_TEXT_DOMAIN),
			'section'	=> 'nmd_section_pickup_article',
			'settings'	=> 'nmd_pickup_article_type_2column',
			'type'		=> 'select',
			'choices'	=> array(
				'sm1-mid2'	=> __('小1+中2（3記事）', NMD_TEXT_DOMAIN),
				'mid1-sm3'	=> __('中1+小3（4記事）', NMD_TEXT_DOMAIN),
			),
		));
		$wp_customize->add_setting('nmd_pickup_article_title', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		));
		$wp_customize->add_control('nmd_pickup_article_title', array(
			'label'			=> __('ピックアップ記事のタイトル', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_pickup_article',
			'settings'		=> 'nmd_pickup_article_title',
			'type'			=> 'text',
		));

		/**
		 * 記事一覧のタイトル =========================================================
		 */
		$wp_customize->add_section('nmd_section_entries_title', array(
			'title'       => __('記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページ記事一覧のタイトル', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_setting('nmd_entries_title_top', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> __('新着記事', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_control('nmd_entries_title_top', array(
			'label'			=> __('記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'description'	=> __('トップページ記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_entries_title',
			'settings'		=> 'nmd_entries_title_top',
			'type'			=> 'text',
		));
		$wp_customize->selective_refresh->add_partial('nmd_entries_title_top', array(
			'selector' => '#entries-ttl-top',
		));
		$wp_customize->add_setting('nmd_entries_title', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> __('記事一覧', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_control('nmd_entries_title', array(
			'label'			=> __('2ページ目以降のタイトル', NMD_TEXT_DOMAIN),
			'description'	=> __('記事一覧2ページ目以降のタイトル', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_entries_title',
			'settings'		=> 'nmd_entries_title',
			'type'			=> 'text',
		));
		$wp_customize->selective_refresh->add_partial('nmd_entries_title', array(
			'selector' => '#entries-ttl',
		));

		/**
		 * 指定カテゴリーの新着記事 =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_category_latest', array(
			'title'       => __('指定カテゴリーの新着記事', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページに指定カテゴリーの新着記事を表示させます', NMD_TEXT_DOMAIN)
		) );
		$wp_customize->add_setting( 'nmd_category_latest_ids', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_category_latest_ids', array(
			'label'			=> __('カテゴリーID', NMD_TEXT_DOMAIN),
			'description'	=> __('カテゴリーIDをコンマ区切りで記述してください。<br>例: 1,5,12', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_category_latest',
			'settings'		=> 'nmd_category_latest_ids',
			'type'			=> 'text',
		) );
	}
	add_action( 'customize_register', 'nmd_customizer_register_top' );
}