<?php
/**
 * Filters.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// 本文中にアドセンス表示
function nmd_add_ads_before_heading( $content ) {

	if ( empty( $ads = get_option( 'nmd_adsense_auto_post_code' ) ) ) return $content;

    if ( !is_singular() ) return $content;

    $post_type = get_post_type();

	if ( !empty ( get_option( 'nmd_adsense_auto_post_type' ) ) ) {
		//固定ページも含む
		$post_type_bool = $post_type === 'post' || $post_type === 'page';
	} else {
		//固定ページは含まない
		$post_type_bool = $post_type === 'post';
	}

	if ( $post_type_bool ) {

		$post_id = get_the_ID();
		$hide_ad_value = get_post_meta( $post_id, 'no_ad', true );

		if ( $hide_ad_value === 'is-off' ) return $content;

		$count_h_list = array();

		if ( ! empty( get_theme_mod( 'nmd_adsense_include_h2', true) ) ) array_push( $count_h_list, "2" );
		if ( ! empty( get_theme_mod( 'nmd_adsense_include_h3', true) ) ) array_push( $count_h_list, "3" );
		if ( ! empty( get_theme_mod( 'nmd_adsense_include_h4', true) ) ) array_push( $count_h_list, "4" );
		if ( ! empty( get_theme_mod( 'nmd_adsense_include_h5', true) ) ) array_push( $count_h_list, "5" );
		if ( ! empty( get_theme_mod( 'nmd_adsense_include_h6', true) ) ) array_push( $count_h_list, "6" );

		$count_h_list = implode( '|', $count_h_list );
		
		if ( empty( $count_h_list ) ) return $content;
		/**
		 * 全く同じ見出しがあるとバグるのでdata属性を入れてかぶらないようにする
		 */
		$heading_replace_regex = "/(<[hH][$count_h_list].*?)(>.*<\/[hH][$count_h_list]>)/";
		
		$num = 1;
		$content = preg_replace_callback(
			$heading_replace_regex,
			function( $matches ) use ( &$num ) {
				$result = $matches[1] . ' data-h-num="heading-' . $num . '" ' . $matches[2];
				$num++;
				return $result;
			},
			$content
		);
		$heading_regex = "/<[hH][$count_h_list].*?>.*<\/[hH][$count_h_list]>/";

		if ( preg_match_all( $heading_regex, $content, $headings ) ) {

			$first_pos = !empty( get_option( 'nmd_adsense_auto_post_first' ) ) ? get_option( 'nmd_adsense_auto_post_first' ) : '1';
			$freq_pos = !empty( get_option( 'nmd_adsense_auto_post_pos' ) ) ? get_option( 'nmd_adsense_auto_post_pos' ) : '5';

			$first_pos = $first_pos - 1;

			$insert_post = $first_pos;

			$src = false;
			$ins = false;

			if ( !empty( get_option( 'nmd_adsense_available_lazyload' ) ) ) {
				
				$ads = str_replace( array("\r\n", "\r", "\n"), "", $ads );

				$pattern = '/<script.*?src\s*=\s*[\"|\'](.*?)[\"|\'].*?>/i';
				if ( preg_match( $pattern, $ads, $matches) ) {
					$src = $matches[1];
				}

				$pattern2 = '/<ins.*?<\/ins>/';
				if ( preg_match( $pattern2, $ads, $matches) ) {
					$ins = $matches[0];
				}
			}

			if ( $src && $ins ) {
				$adcode = '<div class="adsense-wrap" data-adsrc="' . $src . '">' . $ins . '</div>';
			} else {
				$adcode = '<div class="adsense-wrap">' . $ads . '</div>';
			}

			if ( $headings[0] ) {

				$headings_array = $headings[0];

				$heading_num = count( $headings_array );

				for ( $i = 0; $i<$heading_num; $i++ ) {

					if ( $i === $insert_post ) {

						if ( $headings_array[$i] ) {
							$content  = str_replace($headings_array[$i], $adcode.$headings_array[$i], $content);
						}

						$insert_post += $freq_pos;
					}
				}
			}
		}
	}
	return $content;
}
add_filter( 'the_content', 'nmd_add_ads_before_heading', 20 );

/**
 * ウィジェットブロックの見出しをpタグに変更
 */
function nmd_replace_heading_tag( $content ) {

    if ( !is_singular() ) return $content;

	$seach = '/<h2 class="widget__title(.*)">(.*)<\/h2>/';
	$replace = "<p class=\"widget__title$1\">$2</p>";

	$result = preg_replace($seach, $replace, $content);

	return $result;
}
add_filter( 'the_content', 'nmd_replace_heading_tag', 10 );

/**
 * scriptタグにasyncを追加
 */
if( ! function_exists( 'nmd_add_async_js' ) ) {
    function nmd_add_async_js ( $tag, $handle ) {
        if(
            $handle === 'lazyload-ads' || $handle === 'lazyload-tw-insta'
        ) {
            return str_replace( 'src=', ' async src=', $tag );
        }

        return $tag;
    }
    add_filter( 'script_loader_tag', 'nmd_add_async_js', 10, 2 );
}

/**
 * タイトルのカスタマイズ
 */
if( !function_exists( 'nmd_document_title_parts' ) ) {
    function nmd_document_title_parts( $title ) {

        if ( is_front_page() ) {
            if ( get_option( 'nmd_top_title' ) === 'sitename_only' ) $title['tagline'] = '';
        } else {

            $tagline_state = get_option( 'nmd_lowerpage_title', 'title_sitename' );

            if ( $tagline_state === 'title_sitename_tagline' ) $title['tagline'] = NMD_BLOG_DESCRIPTION;
            if ( $tagline_state === 'title_only' ) $title['site'] = '';

            if ( is_singular() ) {
                $seo_title = get_post_meta( get_the_ID(), 'seo_title', true);
                if( !empty( $seo_title ) ) $title['title'] = $seo_title;
            } else if ( is_category() ) {
                $title['title'] = '「' . $title['title'] . '」カテゴリーの記事一覧';
            } else if ( is_tag() ) {
                $title['title'] = '「' . $title['title'] . '」タグの記事一覧';
            } else if ( is_archive() ) {
                $title['title'] = $title['title'] . 'の記事一覧';
            } else if ( is_404() ) {
                $title['title'] = '404 not found';
            }
        }
    
        return $title;
    }
    add_filter( 'document_title_parts', 'nmd_document_title_parts', 10, 1 );
}

/**
 * 記事一覧にIDを表示
 */
function nmd_add_column_name($columns)
{
	global $post;
	if (get_post_type($post) === 'post') {
		$columns['item_id'] = __("記事ID", NMD_TEXT_DOMAIN);
	}
	return $columns;
}
add_filter('manage_posts_columns', 'nmd_add_column_name');


//item_idの項目に値を表示
function nmd_add_column_value($column_name, $post_id)
{
	if ($column_name == 'item_id') {
		echo $post_id;
	}
}
add_filter('manage_posts_custom_column', 'nmd_add_column_value', 10, 2);